@@ -1,21 +1,18 @@
 
 package Moose;
 
-use strict;
-use warnings;
-
 use 5.008;
 
-our $VERSION   = '0.68';
+our $VERSION   = '0.81';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
 use Scalar::Util 'blessed';
-use Carp         'confess', 'croak', 'cluck';
+use Carp         'confess';
 
 use Moose::Exporter;
 
-use Class::MOP 0.76;
+use Class::MOP 0.85;
 
 use Moose::Meta::Class;
 use Moose::Meta::TypeConstraint;
@@ -44,7 +41,7 @@ sub _caller_info {
 }
 
 sub throw_error {
-    # FIXME This 
+    # FIXME This
     shift;
     goto \&confess
 }
@@ -52,24 +49,12 @@ sub throw_error {
 sub extends {
     my $class = shift;
 
-    croak "Must derive at least one class" unless @_;
-
-    my @supers = @_;
-    foreach my $super (@supers) {
-        Class::MOP::load_class($super);
-        croak "You cannot inherit from a Moose Role ($super)"
-            if $super->can('meta')  && 
-               blessed $super->meta &&
-               $super->meta->isa('Moose::Meta::Role')
-    }
-
-
+    Moose->throw_error("Must derive at least one class") unless @_;
 
     # this checks the metaclass to make sure
     # it is correct, sometimes it can get out
     # of sync when the classes are being built
-    my $meta = Moose::Meta::Class->initialize($class);
-    $meta->superclasses(@supers);
+    Moose::Meta::Class->initialize($class)->superclasses(@_);
 }
 
 sub with {
@@ -80,7 +65,10 @@ sub with {
 sub has {
     my $class = shift;
     my $name  = shift;
-    croak 'Usage: has \'name\' => ( key => value, ... )' if @_ == 1;
+
+    Moose->throw_error('Usage: has \'name\' => ( key => value, ... )')
+        if @_ % 2 == 1;
+
     my %options = ( definition_context => _caller_info(), @_ );
     my $attrs = ( ref($name) eq 'ARRAY' ) ? $name : [ ($name) ];
     Class::MOP::Class->initialize($class)->add_attribute( $_, %options ) for @$attrs;
@@ -221,7 +209,7 @@ sub init_meta {
         my $method_meta = $class->meta;
 
         ( blessed($method_meta) && $method_meta->isa('Moose::Meta::Class') )
-            || Moose->throw_error("$class already has a &meta function, but it does not return a Moose::Meta::Class ($meta)");
+            || Moose->throw_error("$class already has a &meta function, but it does not return a Moose::Meta::Class ($method_meta)");
 
         $meta = $method_meta;
     }
@@ -276,6 +264,7 @@ $_->make_immutable(
     Moose::Meta::Role
     Moose::Meta::Role::Method
     Moose::Meta::Role::Method::Required
+    Moose::Meta::Role::Method::Conflicting
 
     Moose::Meta::Role::Composite
 
@@ -337,9 +326,9 @@ metaclass programming as well.
 
 =head2 New to Moose?
 
-If you're new to Moose, the best place to start is the L<Moose::Intro>
-docs, followed by the L<Moose::Cookbook>. The intro will show you what
-Moose is, and how it makes Perl 5 OO better.
+If you're new to Moose, the best place to start is the
+L<Moose::Manual> docs, followed by the L<Moose::Cookbook>. The intro
+will show you what Moose is, and how it makes Perl 5 OO better.
 
 The cookbook recipes on Moose basics will get you up to speed with
 many of Moose's features quickly. Once you have an idea of what Moose
@@ -371,7 +360,7 @@ or coercion.
 
 =head1 PROVIDED METHODS
 
-Moose provides a number of methods to all your classes, mostly through the 
+Moose provides a number of methods to all your classes, mostly through the
 inheritance of L<Moose::Object>. There is however, one exception.
 
 =over 4
@@ -401,7 +390,7 @@ superclasses still properly inherit from L<Moose::Object>.
 
 =item B<with (@roles)>
 
-This will apply a given set of C<@roles> to the local class. 
+This will apply a given set of C<@roles> to the local class.
 
 =item B<has $name|@$names =E<gt> %options>
 
@@ -449,9 +438,10 @@ is expected to have consumed.
 
 =item I<required =E<gt> (1|0)>
 
-This marks the attribute as being required. This means a I<defined> value must be
-supplied during class construction, and the attribute may never be set to
-C<undef> with an accessor.
+This marks the attribute as being required. This means a value must be
+supplied during class construction, I<or> the attribute must be lazy
+and have either a default or a builder. Note that c<required> does not
+say anything about the attribute's value, which can be C<undef>.
 
 =item I<weak_ref =E<gt> (1|0)>
 
@@ -471,11 +461,10 @@ This is only legal if your C<isa> option is either C<ArrayRef> or C<HashRef>.
 
 =item I<trigger =E<gt> $code>
 
-The I<trigger> option is a CODE reference which will be called after the value of
-the attribute is set. The CODE ref will be passed the instance itself, the
-updated value and the attribute meta-object (this is for more advanced fiddling
-and can typically be ignored). You B<cannot> have a trigger on a read-only
-attribute. 
+The I<trigger> option is a CODE reference which will be called after
+the value of the attribute is set. The CODE ref will be passed the
+instance itself and the updated value. You B<cannot> have a trigger on
+a read-only attribute.
 
 B<NOTE:> Triggers will only fire when you B<assign> to the attribute,
 either in the constructor, or using the writer. Default and built values will
@@ -505,9 +494,9 @@ almost never want to do this, since it usually breaks your class. As with
 overriding locally defined methods, if you do want to do this, you should do it
 manually, not with Moose.
 
-You do not I<need> to have a reader (or accessor) for the attribute in order 
-to delegate to it. Moose will create a means of accessing the value for you, 
-however this will be several times B<less> efficient then if you had given 
+You do not I<need> to have a reader (or accessor) for the attribute in order
+to delegate to it. Moose will create a means of accessing the value for you,
+however this will be several times B<less> efficient then if you had given
 the attribute a reader (or accessor) to use.
 
 Below is the documentation for each option format:
@@ -591,7 +580,7 @@ a HASH ref) of the methods you want mapped.
 This tells the class to use a custom attribute metaclass for this particular
 attribute. Custom attribute metaclasses are useful for extending the
 capabilities of the I<has> keyword: they are the simplest way to extend the MOP,
-but they are still a fairly advanced topic and too much to cover here, see 
+but they are still a fairly advanced topic and too much to cover here, see
 L<Moose::Cookbook::Meta::Recipe1> for more information.
 
 The default behavior here is to just load C<$metaclass_name>; however, we also
@@ -604,8 +593,8 @@ B<Moose::Meta::Attribute::Custom::$metaclass_name> as the metaclass name.
 
 =item I<traits =E<gt> [ @role_names ]>
 
-This tells Moose to take the list of C<@role_names> and apply them to the 
-attribute meta-object. This is very similar to the I<metaclass> option, but 
+This tells Moose to take the list of C<@role_names> and apply them to the
+attribute meta-object. This is very similar to the I<metaclass> option, but
 allows you to use more than one extension at a time.
 
 See L<TRAIT NAME RESOLUTION> for details on how a trait name is
@@ -619,7 +608,7 @@ example.
 The value of this key is the name of the method that will be called to
 obtain the value used to initialize the attribute. See the L<builder
 option docs in Class::MOP::Attribute|Class::MOP::Attribute/builder>
-for more information.
+ and/or L<Moose::Cookbook::Basics::Recipe9> for more information.
 
 =item I<default> => SCALAR | CODE
 
@@ -664,7 +653,7 @@ information.
 =item B<has +$name =E<gt> %options>
 
 This is variation on the normal attribute creator C<has> which allows you to
-clone and extend an attribute from a superclass or from a role. Here is an 
+clone and extend an attribute from a superclass or from a role. Here is an
 example of the superclass usage:
 
   package Foo;
@@ -705,12 +694,12 @@ Here is another example, but within the context of a role:
 
   has '+message' => (default => 'Hello I am My::Foo');
 
-In this case, we are basically taking the attribute which the role supplied 
-and altering it within the bounds of this feature. 
+In this case, we are basically taking the attribute which the role supplied
+and altering it within the bounds of this feature.
 
-Aside from where the attributes come from (one from superclass, the other 
-from a role), this feature works exactly the same. This feature is restricted 
-somewhat, so as to try and force at least I<some> sanity into it. You are only 
+Aside from where the attributes come from (one from superclass, the other
+from a role), this feature works exactly the same. This feature is restricted
+somewhat, so as to try and force at least I<some> sanity into it. You are only
 allowed to change the following attributes:
 
 =over 4
@@ -737,12 +726,12 @@ Change if the attribute lazily initializes the slot.
 
 =item I<isa>
 
-You I<are> allowed to change the type without restriction. 
+You I<are> allowed to change the type without restriction.
 
-It is recommended that you use this freedom with caution. We used to 
-only allow for extension only if the type was a subtype of the parent's 
-type, but we felt that was too restrictive and is better left as a 
-policy decision. 
+It is recommended that you use this freedom with caution. We used to
+only allow for extension only if the type was a subtype of the parent's
+type, but we felt that was too restrictive and is better left as a
+policy decision.
 
 =item I<handles>
 
@@ -807,7 +796,7 @@ C<augment> work is best described in the L<Moose::Cookbook::Basics::Recipe6>.
 =item B<confess>
 
 This is the C<Carp::confess> function, and exported here because I use it
-all the time. 
+all the time.
 
 =item B<blessed>
 
@@ -817,10 +806,13 @@ C<ref> anywhere you need to test for an object's class name.
 
 =back
 
-=head1 METACLASS TRAITS
+=head1 METACLASS
 
-When you use Moose, you can also specify traits which will be applied
-to your metaclass:
+When you use Moose, you can specify which metaclass to use:
+
+    use Moose -metaclass => 'My::Meta::Class';
+
+You can also specify traits which will be applied to your metaclass:
 
     use Moose -traits => 'My::Trait';
 
@@ -828,7 +820,7 @@ This is very similar to the attribute traits feature. When you do
 this, your class's C<meta> object will have the specified traits
 applied to it. See L<TRAIT NAME RESOLUTION> for more details.
 
-=head1 TRAIT NAME RESOLUTION
+=head2 Trait Name Resolution
 
 By default, when given a trait name, Moose simply tries to load a
 class of the same name. If such a class does not exist, it then looks
@@ -882,7 +874,9 @@ specified by C<for_class>. This method injects a a C<meta> accessor
 into the class so you can get at this object. It also sets the class's
 superclass to C<base_class>, with L<Moose::Object> as the default.
 
-You can specify an alternate metaclass with the C<metaclass> parameter.
+C<init_meta> returns the metaclass object for C<$class>.
+
+You can specify an alternate metaclass with the C<metaclass> option.
 
 For more detail on this topic, see L<Moose::Cookbook::Extending::Recipe2>.
 
@@ -946,11 +940,11 @@ unresolvable conflict.
 
 =head2 The MooseX:: namespace
 
-Generally if you're writing an extension I<for> Moose itself you'll want 
-to put your extension in the C<MooseX::> namespace. This namespace is 
-specifically for extensions that make Moose better or different in some 
-fundamental way. It is traditionally B<not> for a package that just happens 
-to use Moose. This namespace follows from the examples of the C<LWPx::> 
+Generally if you're writing an extension I<for> Moose itself you'll want
+to put your extension in the C<MooseX::> namespace. This namespace is
+specifically for extensions that make Moose better or different in some
+fundamental way. It is traditionally B<not> for a package that just happens
+to use Moose. This namespace follows from the examples of the C<LWPx::>
 and C<DBIx::> namespaces that perform the same function for C<LWP> and C<DBI>
 respectively.
 
@@ -1039,7 +1033,7 @@ See L<http://search.cpan.org/search?query=MooseX::> for extensions.
 
 =item The Art of the MetaObject Protocol
 
-I mention this in the L<Class::MOP> docs too, this book was critical in 
+I mention this in the L<Class::MOP> docs too, this book was critical in
 the development of both modules and is highly recommended.
 
 =back
@@ -1059,27 +1053,34 @@ want to understand them, I suggest you read this.
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+exception.
+
+Please report any bugs to C<bug-moose@rt.cpan.org>, or through the web
+interface at L<http://rt.cpan.org>.
 
 =head1 FEATURE REQUESTS
 
-We are very strict about what features we add to the Moose core, especially 
-the user-visible features. Instead we have made sure that the underlying 
-meta-system of Moose is as extensible as possible so that you can add your 
-own features easily. That said, occasionally there is a feature needed in the 
-meta-system to support your planned extension, in which case you should 
-either email the mailing list or join us on irc at #moose to discuss.
+We are very strict about what features we add to the Moose core, especially
+the user-visible features. Instead we have made sure that the underlying
+meta-system of Moose is as extensible as possible so that you can add your
+own features easily.
+
+That said, occasionally there is a feature needed in the meta-system
+to support your planned extension, in which case you should either
+email the mailing list (moose@perl.org) or join us on IRC at
+L<irc://irc.perl.org/#moose> to discuss. The
+L<Moose::Manual::Contributing> has more detail about how and when you
+can contribute.
 
 =head1 AUTHOR
 
-Moose is an open project, there are at this point dozens of people who have 
-contributed, and can contribute. If you have added anything to the Moose 
+Moose is an open project, there are at this point dozens of people who have
+contributed, and can contribute. If you have added anything to the Moose
 project you have a commit bit on this file and can add your name to the list.
 
 =head2 CABAL
 
-However there are only a few people with the rights to release a new version 
+However there are only a few people with the rights to release a new version
 of Moose. The Moose Cabal are the people to go to with questions regarding
 the wider purview of Moose, and help out maintaining not just the code
 but the community as well.
