@@ -4,7 +4,7 @@ package Moose::Meta::Method::Accessor;
 use strict;
 use warnings;
 
-our $VERSION   = '0.68';
+our $VERSION   = '0.81';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -39,7 +39,7 @@ sub _eval_code {
         or $self->throw_error("Could not create writer for '${\$self->associated_attribute->name}' because $@ \n code: $code", error => $@, data => $code );
 }
 
-sub generate_accessor_method_inline {
+sub _generate_accessor_method_inline {
     my $self        = $_[0];
     my $attr        = $self->associated_attribute;
     my $attr_name   = $attr->name;
@@ -52,7 +52,7 @@ sub generate_accessor_method_inline {
     . 'if (scalar(@_) >= 2) {' . "\n"
         . $self->_inline_copy_value . "\n"
         . $self->_inline_check_required . "\n"
-        . $self->_inline_check_coercion . "\n"
+        . $self->_inline_check_coercion($value_name) . "\n"
         . $self->_inline_check_constraint($value_name) . "\n"
         . $self->_inline_store($inv, $value_name) . "\n"
         . $self->_inline_trigger($inv, $value_name) . "\n"
@@ -63,7 +63,7 @@ sub generate_accessor_method_inline {
     . ' }');
 }
 
-sub generate_writer_method_inline {
+sub _generate_writer_method_inline {
     my $self        = $_[0];
     my $attr        = $self->associated_attribute;
     my $attr_name   = $attr->name;
@@ -75,7 +75,7 @@ sub generate_writer_method_inline {
     . $self->_inline_pre_body(@_)
     . $self->_inline_copy_value
     . $self->_inline_check_required
-    . $self->_inline_check_coercion
+    . $self->_inline_check_coercion($value_name)
     . $self->_inline_check_constraint($value_name)
     . $self->_inline_store($inv, $value_name)
     . $self->_inline_post_body(@_)
@@ -83,7 +83,7 @@ sub generate_writer_method_inline {
     . ' }');
 }
 
-sub generate_reader_method_inline {
+sub _generate_reader_method_inline {
     my $self        = $_[0];
     my $attr        = $self->associated_attribute;
     my $attr_name   = $attr->name;
@@ -109,33 +109,35 @@ sub _value_needs_copy {
     return $attr->should_coerce;
 }
 
-sub generate_reader_method { shift->generate_reader_method_inline(@_) }
-sub generate_writer_method { shift->generate_writer_method_inline(@_) }
-sub generate_accessor_method { shift->generate_accessor_method_inline(@_) }
-sub generate_predicate_method { shift->generate_predicate_method_inline(@_) }
-sub generate_clearer_method { shift->generate_clearer_method_inline(@_) }
+sub _generate_reader_method { shift->_generate_reader_method_inline(@_) }
+sub _generate_writer_method { shift->_generate_writer_method_inline(@_) }
+sub _generate_accessor_method { shift->_generate_accessor_method_inline(@_) }
+sub _generate_predicate_method { shift->_generate_predicate_method_inline(@_) }
+sub _generate_clearer_method { shift->_generate_clearer_method_inline(@_) }
 
 sub _inline_pre_body  { '' }
 sub _inline_post_body { '' }
 
 sub _inline_check_constraint {
     my ($self, $value) = @_;
-    
+
     my $attr = $self->associated_attribute;
     my $attr_name = $attr->name;
-    
+
     return '' unless $attr->has_type_constraint;
-    
+
     my $type_constraint_name = $attr->type_constraint->name;
 
     qq{\$type_constraint->($value) || } . $self->_inline_throw_error(qq{"Attribute ($attr_name) does not pass the type constraint because: " . \$type_constraint_obj->get_message($value)}, "data => $value") . ";";
 }
 
 sub _inline_check_coercion {
-    my $attr = (shift)->associated_attribute;
-    
+    my ($self, $value) = @_;
+
+    my $attr = $self->associated_attribute;
+
     return '' unless $attr->should_coerce;
-    return '$val = $attr->type_constraint->coerce($_[1]);'
+    return "$value = \$attr->type_constraint->coerce($value);";
 }
 
 sub _inline_check_required {
@@ -143,7 +145,7 @@ sub _inline_check_required {
     my $attr = $self->associated_attribute;
 
     my $attr_name = $attr->name;
-    
+
     return '' unless $attr->is_required;
     return qq{(\@_ >= 2) || } . $self->_inline_throw_error(qq{"Attribute ($attr_name) is required, so cannot be set to undef"}) . ';' # defined $_[1] is not good enough
 }
@@ -164,7 +166,7 @@ sub _inline_check_lazy {
         if ($attr->has_default || $attr->has_builder) {
             if ($attr->has_default) {
                 $code .= '    my $default = $attr->default(' . $instance . ');'."\n";
-            } 
+            }
             elsif ($attr->has_builder) {
                 $code .= '    my $default;'."\n".
                          '    if(my $builder = '.$instance.'->can($attr->builder)){ '."\n".
@@ -172,28 +174,25 @@ sub _inline_check_lazy {
                          '        ' . $self->_inline_throw_error(q{sprintf "%s does not support builder method '%s' for attribute '%s'", ref(} . $instance . ') || '.$instance.', $attr->builder, $attr->name') .
                          ';'. "\n    }";
             }
-            $code .= '    $default = $type_constraint_obj->coerce($default);'."\n"  if $attr->should_coerce;
-            $code .= '    ($type_constraint->($default))' .
-                     '            || ' . $self->_inline_throw_error('"Attribute (" . $attr_name . ") does not pass the type constraint ("' .
-                     '           . $type_constraint_name . ") with " . (defined($default) ? overload::StrVal($default) : "undef")' ) . ';' 
-                     . "\n";
+            $code .= $self->_inline_check_coercion('$default') . "\n";
+            $code .= $self->_inline_check_constraint('$default') . "\n";
             $code .= '    ' . $self->_inline_init_slot($attr, $instance, $slot_access, '$default') . "\n";
-        } 
+        }
         else {
             $code .= '    ' . $self->_inline_init_slot($attr, $instance, $slot_access, 'undef') . "\n";
         }
 
     } else {
         if ($attr->has_default) {
-            $code .= '    ' . $self->_inline_init_slot($attr, $instance, $slot_access, ('$attr->default(' . $instance . ')')) . "\n";            
-        } 
+            $code .= '    ' . $self->_inline_init_slot($attr, $instance, $slot_access, ('$attr->default(' . $instance . ')')) . "\n";
+        }
         elsif ($attr->has_builder) {
-            $code .= '    if (my $builder = '.$instance.'->can($attr->builder)) { ' . "\n" 
-                  .  '       ' . $self->_inline_init_slot($attr, $instance, $slot_access, ($instance . '->$builder'))           
+            $code .= '    if (my $builder = '.$instance.'->can($attr->builder)) { ' . "\n"
+                  .  '       ' . $self->_inline_init_slot($attr, $instance, $slot_access, ($instance . '->$builder'))
                   .  "\n    } else {\n"
                   .  '        ' . $self->_inline_throw_error(q{sprintf "%s does not support builder method '%s' for attribute '%s'", ref(} . $instance . ') || '.$instance.', $attr->builder, $attr->name')
                   .  ';'. "\n    }";
-        } 
+        }
         else {
             $code .= '    ' . $self->_inline_init_slot($attr, $instance, $slot_access, 'undef') . "\n";
         }
@@ -209,18 +208,17 @@ sub _inline_init_slot {
     }
     else {
         return ($slot_access . ' = ' . $value . ';');
-    }    
+    }
 }
 
 sub _inline_store {
     my ($self, $instance, $value) = @_;
     my $attr = $self->associated_attribute;
-    
+
     my $mi = $attr->associated_class->get_meta_instance;
-    my $slot_name = sprintf "'%s'", $attr->slots;
-    
-    my $code = $mi->inline_set_slot_value($instance, $slot_name, $value)    . ";";
-    $code   .= $mi->inline_weaken_slot_value($instance, $slot_name, $value) . ";"
+
+    my $code = $mi->inline_set_slot_value($instance, $attr->slots, $value)    . ";";
+    $code   .= $mi->inline_weaken_slot_value($instance, $attr->slots, $value) . ";"
         if $attr->is_weak_ref;
     return $code;
 }
@@ -235,31 +233,28 @@ sub _inline_trigger {
 sub _inline_get {
     my ($self, $instance) = @_;
     my $attr = $self->associated_attribute;
-    
-    my $mi = $attr->associated_class->get_meta_instance;
-    my $slot_name = sprintf "'%s'", $attr->slots;
 
-    return $mi->inline_get_slot_value($instance, $slot_name);
+    my $mi = $attr->associated_class->get_meta_instance;
+
+    return $mi->inline_get_slot_value($instance, $attr->slots);
 }
 
 sub _inline_access {
     my ($self, $instance) = @_;
     my $attr = $self->associated_attribute;
-    
-    my $mi = $attr->associated_class->get_meta_instance;
-    my $slot_name = sprintf "'%s'", $attr->slots;
 
-    return $mi->inline_slot_access($instance, $slot_name);
+    my $mi = $attr->associated_class->get_meta_instance;
+
+    return $mi->inline_slot_access($instance, $attr->slots);
 }
 
 sub _inline_has {
     my ($self, $instance) = @_;
     my $attr = $self->associated_attribute;
-    
-    my $mi = $attr->associated_class->get_meta_instance;
-    my $slot_name = sprintf "'%s'", $attr->slots;
 
-    return $mi->inline_is_slot_initialized($instance, $slot_name);
+    my $mi = $attr->associated_class->get_meta_instance;
+
+    return $mi->inline_is_slot_initialized($instance, $attr->slots);
 }
 
 sub _inline_auto_deref {
@@ -296,35 +291,12 @@ Moose::Meta::Method::Accessor - A Moose Method metaclass for accessors
 
 =head1 DESCRIPTION
 
-This is a subclass of L<Class::MOP::Method::Accessor> and it's primary
-responsibility is to generate the accessor methods for attributes. It
-can handle both closure based accessors, as well as inlined source based
-accessors.
+This class is a subclass of L<Class::MOP::Method::Accessor> that
+provides additional Moose-specific functionality, all of which is
+private.
 
-This is a fairly new addition to the MOP, but this will play an important
-role in the optimization strategy we are currently following.
-
-=head1 METHODS
-
-=over 4
-
-=item B<generate_accessor_method>
-
-=item B<generate_reader_method>
-
-=item B<generate_writer_method>
-
-=item B<generate_predicate_method>
-
-=item B<generate_clearer_method>
-
-=item B<generate_accessor_method_inline>
-
-=item B<generate_reader_method_inline>
-
-=item B<generate_writer_method_inline>
-
-=back
+To understand this class, you should read the the
+L<Class::MOP::Method::Accessor> documentation.
 
 =head1 BUGS
 
